@@ -16,7 +16,6 @@ from __future__ import division, print_function, absolute_import
 
 __version__ = '0.1'
 
-import os
 import sys
 import copy
 import math
@@ -25,9 +24,14 @@ import operator
 import functools
 import itertools
 
-from collections import Iterable
+try: 
+    # python >= 3.10
+    from collections.abc import Iterable
+except ImportError:
+    from collections import Iterable
 
-from pkg_resources import resource_filename
+# from pkg_resources import resource_filename
+from importlib import resources
 
 from io import BytesIO
 from numbers import Number
@@ -94,12 +98,14 @@ else:
 
 if sys.version < '3':
     from io import open
-    from StringIO import StringIO
-    string_types = basestring
-    _tokenize = lambda input: tokenize.generate_tokens(StringIO(input).readline)
+    from StringIO import StringIO   # noqa
+    string_types = basestring       # noqa
+    def _tokenize(input):
+        return tokenize.generate_tokens(StringIO(input).readline) 
 else:
     string_types = str
-    _tokenize = lambda input: tokenize.tokenize(BytesIO(input.encode('utf-8')).readline)
+    def _tokenize(input):
+        return tokenize.tokenize(BytesIO(input.encode('utf-8')).readline)
 
 PRETTY = '⁰¹²³⁴⁵⁶⁷⁸⁹·⁻'
 
@@ -296,7 +302,7 @@ class UnitsContainer(dict):
         if as_ratio:
             fun = abs
         else:
-            fun = lambda x: x
+            fun = lambda x: x  # noqa: E731
 
         tmp_plus = []
         tmp_minus = []
@@ -461,8 +467,10 @@ class UnitRegistry(object):
 
     # Location of default file
     # _DEFAULT_FILENAME = os.path.join(os.path.dirname(__file__), 'default_en.txt')
-    _DEFAULT_FILENAME = resource_filename('pyphot', 
-                                os.path.join('ezunits','default_en.txt'))
+    #_DEFAULT_FILENAME = resource_filename('pyphot', 
+    #                            os.path.join('ezunits','default_en.txt'))
+    # _DEFAULT_FILENAME = os.path.join(resources.files('pyphot'), 'ezunits','default_en.txt')
+    _DEFAULT_FILENAME = resources.files('pyphot').joinpath('ezunits','default_en.txt')
 
     def __init__(self, filename='', force_ndarray=False):
         self.Quantity = _build_quantity_class(self, force_ndarray)
@@ -544,7 +552,7 @@ class UnitRegistry(object):
 
         for unit_names in _solve_dependencies(dep2):
             for unit_name in unit_names:
-                if not unit_name in self._UNITS:
+                if unit_name not in self._UNITS:
                     self.add_unit(unit_name, *pending[unit_name])
 
     def get_alias(self, name):
@@ -1107,7 +1115,7 @@ def _build_quantity_class(registry, force_ndarray):
             if func.__name__ in self.__require_units:
                 try:
                     self.ito(self.__require_units[func.__name__])
-                except:
+                except Exception:
                     raise ValueError('Quantity must be dimensionless.')
 
             value = func(*args, **kwargs)
@@ -1177,7 +1185,7 @@ def _build_quantity_class(registry, force_ndarray):
                 if uf.__name__ in self.__require_units:
                     try:
                         self.ito(self.__require_units[uf.__name__])
-                    except:
+                    except Exception:
                         raise _Exception(ValueError)
                 return self.magnitude.__array_prepare__(obj, context)
             except _Exception as ex:
@@ -1193,12 +1201,12 @@ def _build_quantity_class(registry, force_ndarray):
                 if uf.__name__ in self.__set_units:
                     try:
                         out = self.__class__(out, self.__set_units[uf.__name__])
-                    except:
+                    except Exception:
                         raise _Exception(ValueError)
                 elif uf.__name__ in self.__copy_units:
                     try:
                         out = self.__class__(out, self.units)
-                    except:
+                    except Exception:
                         raise _Exception(ValueError)
                 elif uf.__name__ in self.__prod_units:
                     tmp = self.__prod_units[uf.__name__]
