@@ -8,7 +8,7 @@ This also include functions to keep libraries up to date
 
 .. note::
 
-    integrations are done using :func:`trapz`
+    integrations are done using :func:`trapezoid`
     Why not Simpsons? Simpsons principle is to take sequence of 3 points to
     make a quadratic interpolation. Which in the end, when filters have sharp
     edges, the error due to this "interpolation" are extremely large in
@@ -17,7 +17,12 @@ This also include functions to keep libraries up to date
 from __future__ import print_function, division
 import numpy as np
 import tables
-from scipy.integrate import trapz
+
+try:
+    from scipy.integrate import trapezoid
+except ImportError:  # older scipy / numpy < 2.0
+    from scipy.integrate import trapz as trapezoid
+    
 from functools import wraps
 
 from .simpletable import SimpleTable
@@ -28,9 +33,7 @@ from .config import libsdir
 import os
 
 # directories
-# __default__      = libsdir + '/filters.hd5'
-# __default__ = libsdir + '/filters'
-__default__ = libsdir + '/new_filters.hd5'
+__default__ = libsdir.joinpath('new_filters.hd5')
 
 
 class Constants(object):
@@ -81,7 +84,7 @@ def _drop_units(q):
     """ Drop the unit definition silently """
     try:
         return q.magnitude
-    except:
+    except AttributeError:
         return q
 
 
@@ -97,18 +100,9 @@ class Filter(object):
     name: str
         name of the filter
 
-    cl: float
-        central wavelength of the filter
-
     norm: float
         normalization factor of the filter
 
-    lpivot: float
-        pivot wavelength of the filter
-
-    wavelength: ndarray
-        wavelength sequence defining the filter transmission curve
-
     transmit: ndarray
         transmission curve of the filter
 
@@ -134,16 +128,16 @@ class Filter(object):
         self._wavelength = self._wavelength[idx]        
         self.transmit   = np.clip(transmit[idx], 0., np.nanmax(transmit))
         
-        self.norm       = trapz(self.transmit, self._wavelength)
-        self._lT        = trapz(self._wavelength * self.transmit, self._wavelength)
+        self.norm       = trapezoid(self.transmit, self._wavelength)
+        self._lT        = trapezoid(self._wavelength * self.transmit, self._wavelength)
         self._lpivot    = self._calculate_lpivot()
         self._cl        = self._lT / self.norm
 
     def _calculate_lpivot(self):
         if 'photon' in self.dtype:
-            lpivot2 = self._lT / trapz(self.transmit / self._wavelength, self._wavelength)
+            lpivot2 = self._lT / trapezoid(self.transmit / self._wavelength, self._wavelength)
         else:
-            lpivot2 = self.norm / trapz(self.transmit / self._wavelength ** 2, self._wavelength)
+            lpivot2 = self.norm / trapezoid(self.transmit / self._wavelength ** 2, self._wavelength)
         return np.sqrt(lpivot2)
 
     def set_wavelength_unit(self, unit):
@@ -395,7 +389,7 @@ class Filter(object):
         if True in ind:
             try:
                 _sflux = sflux[:, ind]
-            except:
+            except Exception:
                 _sflux = sflux[ind]
             # limit integrals to where necessary
             # ind = ifT > 0.
@@ -438,7 +432,7 @@ class Filter(object):
         _lamb = _drop_units(lamb)
         try:
             _unit = str(lamb.units)
-        except:
+        except AttributeError:
             _unit = self.wavelength_unit
         ifT = np.interp(_lamb, _wavelength, self.transmit, left=0., right=0.)
         return self.__class__(_lamb, ifT, name=self.name, dtype=self.dtype, unit=_unit)
@@ -563,7 +557,7 @@ class Filter(object):
         try:
             unit = str(dyn.units)
             dyn = _drop_units(dyn)
-        except:
+        except Exception:
             pass
         w = np.array([lmin - 0.01 * dyn, lmin, lmax, lmax + 0.01 * dyn])
         f = np.array([0., 1., 1., 0.])
@@ -572,9 +566,11 @@ class Filter(object):
     @property
     def AB_zero_mag(self):
         """ AB magnitude zero point
+        
         ABmag = -2.5 * log10(f_nu) - 48.60
               = -2.5 * log10(f_lamb) - 2.5 * log10(lpivot ** 2 / c) - 48.60
               = -2.5 * log10(f_lamb) - zpts
+
         """
         if self.wavelength_unit is None:
             raise AttributeError('Needs wavelength units')
@@ -647,13 +643,10 @@ class UncertainFilter(Filter):
 
     Attributes
     ----------
-    wavelength: ndarray
-        wavelength sequence defining the filter transmission curve
-
-    mean_: Filter
+    mean: Filter
         mean passband transmission
 
-    samples_: sequence(Filter)
+    samples: sequence(Filter)
         samples from the uncertain passband transmission model
 
     name: string
@@ -690,7 +683,7 @@ class UncertainFilter(Filter):
             wavelength to express the model in addition to the training points
         n_samples: int
             number of samples to generate from the model.
-        **kwawrgs: dict
+        kwawrgs: dict
             UncertainFilter keywords
         """
         if xprime is None:
@@ -824,6 +817,7 @@ class UncertainFilter(Filter):
         transmission is half maximum
 
         ..note::
+        
             This calculation is not exact but rounded to the nearest passband
             data points
         """
@@ -953,9 +947,11 @@ class UncertainFilter(Filter):
     @property
     def AB_zero_mag(self):
         """ AB magnitude zero point
+
         ABmag = -2.5 * log10(f_nu) - 48.60
               = -2.5 * log10(f_lamb) - 2.5 * log10(lpivot ** 2 / c) - 48.60
               = -2.5 * log10(f_lamb) - zpts
+
         """
         return self._get_mean_and_samples_attribute('AB_zero_mag')
 
@@ -1100,17 +1096,19 @@ class Library(object):
 
     def to_csv(self, directory='./', progress=True, **kwargs):
         """ Export each filter into a csv file with its own name
+
         Parameters
         ----------
         directory: str
             directory to write into
         progress: bool
             show progress if set
+        
         """
         from .helpers import progress_enumerate
         try:
             os.stat(directory)
-        except:
+        except Exception:
             os.mkdir(directory)
         with self as s:
             for _, k in progress_enumerate(s.content, desc='export', show_progress=progress):
@@ -1122,12 +1120,14 @@ class Library(object):
 
     def to_hdf(self, fname='filters.hd5', progress=True, **kwargs):
         """ Export each filter into a csv file with its own name
+
         Parameters
         ----------
         directory: str
             directory to write into
         progress: bool
             show progress if set
+
         """
         from .helpers import progress_enumerate
         with self as s:
@@ -1203,7 +1203,7 @@ class Ascii_Library(Library):
         """ Load a given filter from the library """
         try:
             fil = Filter.from_ascii(fname, *args, **kwargs)
-        except:
+        except Exception:
             content = self.content
             r = [k for k in content if fname in k]
 
@@ -1362,7 +1362,7 @@ class HDF_Library(Library):
         with self as s:
             try:
                 filters = s.hdf.root.content.cols.TABLENAME[:]
-            except:
+            except Exception:
                 filters = list(s.hdf.root.filters._v_children.keys())
         if hasattr(filters[0], 'decode'):
             filters = [k.decode('utf8') for k in filters]
